@@ -109,9 +109,10 @@ draw_options(#st{bb=Uvs}=AuvSt0) ->
                                         false -> atom_to_list(MatName0);
                                         OldId  ->
                                             OldImg = wings_image:info(OldId),
-                                            case OldImg#e3d_image.name of
-                                                "auvBG" -> atom_to_list(MatName0);
-                                                Other -> Other
+                                            OldName = OldImg#e3d_image.name,
+                                            case string:prefix("auvBG",  OldName) of
+                                                nomatch -> OldName;
+                                                _ ->  atom_to_list(MatName0)
                                             end
                                     end,
                           catch wings_material:update_image(MatName0, diffuse, NewImg#e3d_image{name=TexName}, GeomSt0)
@@ -1116,9 +1117,43 @@ set_viewport({X,Y,W,H}=Viewport, Scale) ->
 %% Data setup 
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
-setup(#st{bb=#uvstate{id=RId,st=#st{shapes=Sh0}}}=St, Reqs) ->
+setup(#st{shapes=ShUV,selmode=SModeUV0,sel=SelUV0,bb=Uvs}=St, Reqs) ->
+    #uvstate{id=RId,matname=MatName,st=#st{shapes=Sh0}} = Uvs,
     We = gb_trees:get(RId,Sh0),
-    {Charts,{_Cnt,UVpos,Vpos,Ns,Ts,BB,Vc}} = setup_charts(St, We, Reqs),
+    {Charts,{_Cnt,UVpos,Vpos,Ns,Ts,BB,Vc}} =
+        case wpc_autouv:get_textureset_info(We) of
+            {?MULTIPLE,[_,[_|_]]} ->
+                Get_mat_face = fun(#we{id=Id}=WeUV) ->
+                        FsMat = wings_facemat:all(WeUV),
+                        case [F || {F,Mat} <- FsMat, Mat==MatName] of
+                            [] -> [];
+                            Fs -> {Id,Fs}
+                        end
+                    end,
+                SelForTile = lists:flatten([Get_mat_face(WeUV) || WeUV <- gb_trees:values(ShUV)]),
+                case SelForTile of
+                    [_|_] ->
+                        if (SelUV0==[]) ->
+                            SModeUV = body,
+                            SelUV = [{Id,gb_sets:singleton(0)} || {Id,_} <- SelForTile];
+                        true ->
+                            SelUV1 = [Sel || {IdSel,_}=Sel <- SelUV0, proplists:is_defined(IdSel,SelForTile)],
+                            case SelUV1 of
+                                [] ->
+                                    SModeUV = face,
+                                    SelUV = [{Id,gb_sets:from_list(Fs)} || {Id,Fs} <- SelForTile];
+                                _ ->
+                                    SModeUV = SModeUV0,
+                                    SelUV = SelUV0
+                            end
+                        end,
+                        setup_charts(St#st{selmode=SModeUV,sel=SelUV}, We, Reqs);
+                    [] ->
+                        setup_charts(St, We, Reqs)
+                end;
+            none ->
+                setup_charts(St, We, Reqs)
+        end,
     #ts{charts=Charts,
 	uv = to_bin(UVpos,uv),
 	pos= to_bin(Vpos,pos),
@@ -1277,7 +1312,7 @@ build_tangents([], _, Bin) -> Bin.
 
 add_tangents1([V|Vs], Ts, H0, N, Prev, Bin0) ->
     case array:get(V, Ts) of
-	{{0.0, 0.0, 0.0}, BiT} ->
+	{{+0.0, +0.0, +0.0}, BiT} ->
 	    {Tan = {X,Y,Z}, H} = get_tangent(Prev, BiT, H0, N),
 	    Bin = <<Bin0/binary, X:?F32,Y:?F32,Z:?F32, H:?F32>>,
 	    add_tangents1(Vs, Ts, H, N, Tan, Bin);
@@ -1294,7 +1329,7 @@ add_tangents1([V|Vs], Ts, H0, N, Prev, Bin0) ->
     end;
 add_tangents1([], _, _, _, _, Bin) -> Bin.
 
-get_tangent(undefined, {0.0,0.0,0.0}, H0, N) ->
+get_tangent(undefined, {+0.0,+0.0,+0.0}, H0, N) ->
     H = if H0 =:= 0 -> -1; true -> H0 end,
     {cross_axis(N), H};
 get_tangent(undefined, BiT, 0, N) ->
