@@ -19,7 +19,7 @@
 -export([init/0,menu/2,command/2]).
 
 -define(NEED_OPENGL, 1).
--include_lib("wings.hrl").
+-include_lib("wings/src/wings.hrl").
 -include_lib("wings/e3d/e3d_image.hrl").
 
 init() ->
@@ -196,10 +196,10 @@ is_plain_geometry(#we{perm=P}=We) ->
 	 ?IS_ANY_LIGHT(We)).
 
 draw_vab(Vab) ->
-    wings_draw_setup:enable_pointers(Vab, []),
+    RS = wings_draw_setup:enable_pointers(Vab, [], #{}),
     Count = wings_draw_setup:face_vertex_count(Vab),
     gl:drawArrays(?GL_TRIANGLES, 0, Count),
-    wings_draw_setup:disable_pointers(Vab, []).
+    wings_draw_setup:disable_pointers(Vab, RS).
 
 get_ao_factor(Buffer) ->
     NumWhitePixels = num_white(Buffer, 0),
@@ -250,20 +250,23 @@ render_hemicube(SX, SY, Eye, Lookat, DF) ->
 render_view(Eye, Lookat, Up, Frustum, Viewport, DrawFun) ->
     Near = 0.01,
     Far = 100.0,
-    {Ex,Ey,Ez} = Eye,
-    {Dx,Dy,Dz} = Lookat,
-    {Ux,Uy,Uz} = Up,
     [L,R,B,T] = [I*Near || I <- Frustum],
     [X,Y,W,H] = Viewport,
     gl:matrixMode(?GL_PROJECTION),
     gl:loadIdentity(),
-    gl:frustum(L,R, B,T, Near,Far),
+    FM = e3d_transform:frustum(L,R, B,T, Near,Far),
+    gl:loadMatrixd(e3d_transform:matrix(FM)),
+
     gl:matrixMode(?GL_MODELVIEW),
     gl:loadIdentity(),
-    glu:lookAt(Ex,Ey,Ez, Dx,Dy,Dz, Ux,Uy,Uz),
+
+    LM = e3d_transform:lookat(Eye, Lookat, Up), 
+    gl:loadMatrixd(e3d_transform:matrix(LM)),
+
     gl:viewport(X,Y, W,H),
     DrawFun().
 
+
 create_ambient_light(St) ->
     case wings_pref:get_value(scene_lights, true) of
         true -> ok;
