@@ -381,6 +381,7 @@ hardness(hard, St) ->
 %%% The Slide command.
 %%%
 
+slide(#st{sel=[]}=St) -> St;
 slide(St0) ->
     Mode = wings_pref:get_value(slide_mode, relative),
     Stop = wings_pref:get_value(slide_stop, false),
@@ -440,6 +441,8 @@ slide_mode(MinUp,MinDw) ->
     end.
 
 slide_units({absolute,_,false},_,_) -> [distance];
+slide_units({absolute,_Freeze,true},unknown,unknown) ->
+    [{distance, {-1.0, 1.0}}];
 slide_units({absolute,_Freeze,true},MinUp,MinDw) ->
     [{distance, {-MinUp, MinDw}}];
 slide_units({relative,_,false},_,_) -> [percent];
