@@ -13,7 +13,8 @@
 
 -module(wings_gl).
 -export([init/1, window/4, attributes/0,
-         setCurrent/2, wxGLCanvas_new/3, %% new wx api variants
+         setCurrent/2, setCurrent/3,
+         wxGLCanvas_new/3, %% new wx api variants
 	 is_ext/1,is_ext/2,
 	 error_string/1]).
 
@@ -34,7 +35,7 @@
 	]).
 
 %% Debugging.
--export([check_error/2]).
+-export([check_error/2, init_extensions/0]).
 
 -define(NEED_OPENGL, 1).
 -include("wings.hrl").
@@ -45,28 +46,37 @@
 -endif.
 
 init(Parent) ->
+    check_for_msaa(),
     GL = window(Parent, undefined, true, false),
     init_extensions(),
     GL.
 
+%%% Intel GPUs have been crashing Wings3D on start. It's related to MSAA management
+%%% by the driver has been turned off on Intel Control Panel.
+%%% To avoid that we cannot initialize GLCanvas with MSAA in case it's not available.
+check_for_msaa() ->
+    MSAA = 
+        try
+            wxGLCanvas:isDisplaySupported ([?WX_GL_SAMPLE_BUFFERS,1,  ?WX_GL_SAMPLES,4, 0])
+        catch _:_Reason:_ST ->
+            false
+        end,
+    wings_pref:set_value(gl_msaa, MSAA),
+    not MSAA andalso io:format("Multisampling (MSAA) not available~n").
+
 attributes() ->
-    SB = case os:type() of
-             {unix, Os} when Os =/= darwin ->
-                 %% Sample buffers does not currently work on Wayland
-                 case os:getenv("XDG_SESSION_TYPE") of
-                     "x11" -> [?WX_GL_SAMPLE_BUFFERS,1, ?WX_GL_SAMPLES,4];
-                     "X11" -> [?WX_GL_SAMPLE_BUFFERS,1, ?WX_GL_SAMPLES,4];
-                     _ -> []
-                 end;
-             _ ->
-                 [?WX_GL_SAMPLE_BUFFERS,1, ?WX_GL_SAMPLES,4]
-         end,
+    %% init Sample buffers attributes if multisampling available
+    SB =
+        case wings_pref:get_value(gl_msaa, true) of
+            true -> [?WX_GL_SAMPLE_BUFFERS,1, ?WX_GL_SAMPLES,4, 0];
+            false -> [0]
+        end,
     {attribList,
      [?WX_GL_RGBA,
       ?WX_GL_MIN_RED,8,?WX_GL_MIN_GREEN,8,?WX_GL_MIN_BLUE,8,
       ?WX_GL_DEPTH_SIZE, 24,
-      ?WX_GL_DOUBLEBUFFER] ++
-         SB ++ [0]
+      ?WX_GL_DOUBLEBUFFER
+     ] ++ SB
     }.
 
 window(Parent, Context0, Connect, Show) ->
@@ -188,14 +198,33 @@ forward_key(_) -> false.
 new_gl_api() ->
     wings_u:is_exported(wxGLCanvas, setCurrent, 2).
 
-setCurrent(GL,Context) ->
+setCurrent(GL, Context) ->
+    setCurrent(GL, Context, false).
+setCurrent(GL, Context0, Recreate0) ->
     SetCurrent = wings_u:id(setCurrent),
+    CreateSurface = wings_u:id(createSurface),
+    Recreate = case os:type() of
+                   {unix, darwin} -> false;
+                   {unix, _} -> Recreate0;
+                   {win32, _} -> false
+               end,
+
     case new_gl_api() of
         false -> wxGLCanvas:SetCurrent(GL);
-        true -> wxGLCanvas:SetCurrent(GL,Context)
+        true when not Recreate ->
+            true = wxGLCanvas:SetCurrent(GL,Context0);
+        true when Recreate ->
+            try  %% EGL surface needs to recreated after reparent
+                true = wxGLCanvas:CreateSurface(GL),
+                Context = wxGLContext:new(GL, [{other, Context0}]),
+                ?SET(gl_context, Context),
+                true = wxGLCanvas:SetCurrent(GL,Context)
+            catch _:_Reason:_ST ->
+                    %% ?dbg("ERROR: ~p in ~p~n", [_Reason, _ST]),
+                    true = wxGLCanvas:SetCurrent(GL,Context0)
+            end
     end.
 
-
 wxGLCanvas_new(Parent, undefined, Ps) ->
     wxGLCanvas:new(Parent, Ps);
 wxGLCanvas_new(Parent, Context, Ps) ->
