@@ -387,7 +387,7 @@ render_wire(Dls, SelMode, false, RS0) ->
         {[],[],[]} -> RS0;
         {Ws,Os,PWs} ->
             case {SelMode,wings_pref:get_value(edge_color)} of
-		{body,{0.0,0.0,0.0}} ->
+		{body,{+0.0,+0.0,+0.0}} ->
 		    gl:color3f(0.3, 0.3, 0.3);
 		{_,EdgeColor} ->
 		    gl:color3fv(EdgeColor)
@@ -957,7 +957,7 @@ show_scale(W, H, Scale) ->
     ScaleStr = float_to_list(float(Scale),[{decimals, 4}, compact]),
     StrScale = ?__(1,"Grid Scale: x")++ScaleStr,
     X = W-wings_text:width(StrScale)-10,
-    wings_io:info(X, H-18, StrScale).
+    wings_io:info(X, H-?LINE_HEIGHT-4, StrScale).
 
 show_saved_bb(St) ->
     Key = get_saved_bb_key(St),
